@@ -20,7 +20,8 @@ class StereoReconstructorWithRectifiedImages(sr.StereoReconstructor):
     """
     def __init__(self,
                  lower_disparity_multiplier=2.0,
-                 upper_disparity_multiplier=2.0):
+                 upper_disparity_multiplier=2.0,
+                 alpha: float = 0):
         """
         Constructor creates some member variables, so this class
         becomes statefull. You call reconstruct() once, and then
@@ -29,6 +30,7 @@ class StereoReconstructorWithRectifiedImages(sr.StereoReconstructor):
 
         :param lower_disparity_multiplier: min=median - (this * std).
         :param upper_disparity_multiplier: max=median + (this * std).
+        :param alpha: opencv alpha parameter for StereoRectify
         """
         super().__init__()
         self.disparity = None
@@ -41,18 +43,17 @@ class StereoReconstructorWithRectifiedImages(sr.StereoReconstructor):
         self.left_rectified = None
         self.right_rectified = None
         self.left_mask = None
+        self.alpha = alpha
 
     # pylint:disable=too-many-arguments
     def reconstruct(self,
                     left_image: np.ndarray,
                     left_camera_matrix: np.ndarray,
-                    left_dist_coeffs: np.ndarray,
                     right_image: np.ndarray,
                     right_camera_matrix: np.ndarray,
-                    right_dist_coeffs: np.ndarray,
                     left_to_right_rmat: np.ndarray,
                     left_to_right_tvec: np.ndarray,
-                    left_mask: np.ndarray = None
+                    left_mask: np.ndarray = None,
                     ):
         """
         Implementation of stereo surface reconstruction that takes
@@ -64,10 +65,8 @@ class StereoReconstructorWithRectifiedImages(sr.StereoReconstructor):
 
         :param left_image: undistorted left image, BGR
         :param left_camera_matrix: [3x3] camera matrix
-        :param left_dist_coeffs: [1xN] distortion coefficients
         :param right_image: undistorted right image, BGR
         :param right_camera_matrix: [3x3] camera matrix
-        :param right_dist_coeffs: [1xN] distortion coefficients
         :param left_to_right_rmat: [3x3] rotation matrix
         :param left_to_right_tvec: [3x1] translation vector
         :param left_mask: mask image, single channel, same size as left_image
@@ -79,23 +78,24 @@ class StereoReconstructorWithRectifiedImages(sr.StereoReconstructor):
 
         self.r_1, r_2, p_1, p_2, q_mat, _, _ = \
             cv2.stereoRectify(left_camera_matrix,
-                              left_dist_coeffs,
+                              None,
                               right_camera_matrix,
-                              right_dist_coeffs,
+                              None,
                               (width, height),
                               left_to_right_rmat,
                               left_to_right_tvec,
+                              alpha=self.alpha
                               )
 
         undistort_rectify_map_l_x, undistort_rectify_map_l_y = \
             cv2.initUndistortRectifyMap(left_camera_matrix,
-                                        left_dist_coeffs,
+                                        None,
                                         self.r_1, p_1,
                                         (width, height), cv2.CV_32FC1)
 
         undistort_rectify_map_r_x, undistort_rectify_map_r_y = \
             cv2.initUndistortRectifyMap(right_camera_matrix,
-                                        right_dist_coeffs,
+                                        None,
                                         r_2, p_2,
                                         (width, height), cv2.CV_32FC1)
 
