@@ -30,9 +30,7 @@ class Register3DToMosaicedStereoVideo:
             surface_reconstructor: sr.StereoReconstructorWithRectifiedImages,
             rigid_registration: rr.RigidRegistration,
             left_camera_matrix: np.ndarray,
-            left_dist_coeffs: np.ndarray,
             right_camera_matrix: np.ndarray,
-            right_dist_coeffs: np.ndarray,
             left_to_right_rmat: np.ndarray,
             left_to_right_tvec: np.ndarray,
             min_number_of_keypoints: int = 25,
@@ -48,9 +46,7 @@ class Register3DToMosaicedStereoVideo:
         :param surface_reconstructor: Mandatory class to do reconstruction.
         :param rigid_registration: Mandatory class to perform rigid alignment.
         :param left_camera_matrix: [3x3] camera matrix.
-        :param left_dist_coeffs: [1x5] distortion coeff's.
         :param right_camera_matrix: [3x3] camera matrix.
-        :param right_dist_coeffs: [1x5] distortion coeff's.
         :param left_to_right_rmat: [3x3] left-to-right rotation matrix.
         :param left_to_right_tvec: [1x3] left-to-right translation vector.
         :param min_number_of_keypoints: Number of keypoints to use for matching.
@@ -66,9 +62,7 @@ class Register3DToMosaicedStereoVideo:
         self.surface_reconstructor = surface_reconstructor
         self.rigid_registration = rigid_registration
         self.left_camera_matrix = left_camera_matrix
-        self.left_dist_coeffs = left_dist_coeffs
         self.right_camera_matrix = right_camera_matrix
-        self.right_dist_coeffs = right_dist_coeffs
         self.left_to_right_rmat = left_to_right_rmat
         self.left_to_right_tvec = left_to_right_tvec
         self.min_number_of_keypoints = min_number_of_keypoints
@@ -167,10 +161,8 @@ class Register3DToMosaicedStereoVideo:
             full_reconstruction = \
                 self.surface_reconstructor.reconstruct(left_image,
                                                        self.left_camera_matrix,
-                                                       self.left_dist_coeffs,
                                                        right_image,
                                                        self.right_camera_matrix,
-                                                       self.right_dist_coeffs,
                                                        self.left_to_right_rmat,
                                                        self.left_to_right_tvec,
                                                        left_mask
